import axios from 'axios'
import { getKeyValue } from './storage.service.js'
import { VARS } from '../variables.js'
import { printError } from './log.service.js'

export const getIcon = (icon) => {
  switch (Number(icon.slice(0, -1))) {
    case 1:
      return '☀'
    case 2:
      return '🌤️'
    case 3:
      return '☁'
    case 4:
      return '☁'
    case 9:
      return '🌧️'
    case 10:
      return '🌦️'
    case 11:
      return '🌩️'
    case 13:
      return '❄'
    case 50:
      return '🌫️'
  }
}

export const getWeather = async (city) => {
  try {
    const token = await getKeyValue(VARS.token)
    if (!token) return printError('Error read API key. Set token via command -t TOKEN')

    const {data} = await axios({
      url: process.env.WEATHER_API_URL,
      method: 'get',
      params: {
        q: city,
        appid: token,
        units: 'metric'
      }
    })

    return data
  } catch(e) {
    if (e?.response?.status === 401) {
      printError('Invalid API key. To change API key, use: weather -t TOKEN ')
    } else if (e?.response?.status === 404) {
      printError('Invalid city. Enter valid city')
    } else {
      printError(e)
    }
  }
}
