import { homedir } from 'os'
import { join } from 'path'
import { promises } from 'fs'
import { printError } from './log.service.js'

const filePath = join(homedir(), 'weather-data.json')

const getKeyValue = async (key) => {
  try {
    if (await isExist(filePath)) {
      const file = await promises.readFile(filePath)
      const data = JSON.parse(file)
      return data[key]
    }
  } catch(e) {
    printError(e)
    return undefined
  }
}

const isExist = async (path) => {
  try {
    await promises.stat(path)
    return true
  } catch (e) {
    printError(e)
    return false
  }
}

const saveKeyValue = async (key, value) => {
  try {
    let data = {}

    if (await isExist(filePath)) {
      const file = await promises.readFile(filePath)
      data = JSON.parse(file)
    }
    data[key] = value
    await promises.writeFile(filePath, JSON.stringify(data))
  } catch(e) {
    printError(e)
  }
}

export {saveKeyValue, getKeyValue}
