#!/usr/bin/env node
import * as dotenv from 'dotenv'
import { getArgs } from './helpers/args.js'
import {
  printHelp,
  printSuccess,
  printError,
  printWeather,
} from './services/log.service.js'
import { getKeyValue, saveKeyValue } from './services/storage.service.js'
import { getIcon, getWeather } from './services/api.service.js'
import { VARS } from './variables.js'

dotenv.config()

const saveToken = async (token) => {
  if (!token.length) return printError('Token unavailable')
  try {
    await saveKeyValue(VARS.token, token)
    printSuccess('Token saved successfully')
  } catch (e) {
    printError(e.message)
  }
}

const saveCity = async (city) => {
  if (!city.length) return printError('City unavailable')
  try {
    await saveKeyValue(VARS.city, city)
    printSuccess('City saved successfully')
  } catch (e) {
    printError(e.message)
  }
}

const getForecast = async () => {
  try {
    const city = await getKeyValue(VARS.city)
    const weather = await getWeather(city)
    printWeather(weather, getIcon(weather.weather[0].icon))
  } catch (e) {
    printError(e)
  }
}

const initCLI = () => {
  const args = getArgs(process.argv)

  if (args.h) {
    return printHelp()
  }

  if (args.t) {
    return saveToken(args.t)
  }

  if (args.s) {
    return saveCity(args.s)
  }

  return getForecast()
}

initCLI()
